package com.dcs.hnyz.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.dcs.hnyz.domain.ActionBinding;

/**
 * 动作关联管理Mapper接口
 * 
 * @author hmy
 * @date 2025-04-28
 */
public interface ActionBindingMapper extends BaseMapper<ActionBinding>
{
    /**
     * 查询动作关联管理
     * 
     * @param id 动作关联管理主键
     * @return 动作关联管理
     */
    public ActionBinding selectActionBindingById(Long id);

    /**
     * 查询动作关联管理列表
     * 
     * @param actionBinding 动作关联管理
     * @return 动作关联管理集合
     */
    public List<ActionBinding> selectActionBindingList(ActionBinding actionBinding);

    /**
     * 新增动作关联管理
     * 
     * @param actionBinding 动作关联管理
     * @return 结果
     */
    public int insertActionBinding(ActionBinding actionBinding);

    /**
     * 修改动作关联管理
     * 
     * @param actionBinding 动作关联管理
     * @return 结果
     */
    public int updateActionBinding(ActionBinding actionBinding);

    /**
     * 删除动作关联管理
     * 
     * @param id 动作关联管理主键
     * @return 结果
     */
    public int deleteActionBindingById(Long id);

    /**
     * 批量删除动作关联管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteActionBindingByIds(Long[] ids);
}
